camelot.camelot.view.plugins.dateeditorplugin

Package camelot :: Package camelot :: Package view :: Package plugins :: Module dateeditorplugin |
[hide private]
[frames] | no frames]

# Source Code for Module camelot.camelot.view.plugins.dateeditorplugin

     1  #  ============================================================================

     2  #

     3  #  Copyright (C) 2007-2008 Conceptive Engineering bvba. All rights reserved.

     4  #  www.conceptive.be / project-camelot@conceptive.be

     5  #

     6  #  This file is part of the Camelot Library.

     7  #

     8  #  This file may be used under the terms of the GNU General Public

     9  #  License version 2.0 as published by the Free Software Foundation

    10  #  and appearing in the file LICENSE.GPL included in the packaging of

    11  #  this file.  Please review the following information to ensure GNU

    12  #  General Public Licensing requirements will be met:

    13  #  http://www.trolltech.com/products/qt/opensource.html

    14  #

    15  #  If you are unsure which license is appropriate for your use, please

    16  #  review the following information:

    17  #  http://www.trolltech.com/products/qt/licensing.html or contact

    18  #  project-camelot@conceptive.be.

    19  #

    20  #  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE

    21  #  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

    22  #

    23  #  For use of this library in commercial applications, please contact

    24  #  project-camelot@conceptive.be

    25  #

    26  #  ============================================================================

    27

    28  from PyQt4 import QtGui, QtDesigner
    29  from camelot.view.plugins import CamelotEditorPlugin
    30

    31 -class DateEditorPlugin(QtDesigner.QPyDesignerCustomWidgetPlugin, CamelotEditorPlugin):
    32

    33 -  def __init__(self, parent = None):
    34      QtDesigner.QPyDesignerCustomWidgetPlugin.__init__(self)
    35      from camelot.view.controls.editors import DateEditor
    36      CamelotEditorPlugin.__init__(self)
    37      self._widget = DateEditor
    38